@@ -1,4 +1,4 @@
 pages = [
     "DelayDiffEq.jl: DDE solvers" => "index.md",
-    "Solver API" => "solvers/api.md"
+    "Solver API" => "solvers/api.md",
 ]
