@@ -1,6 +1,8 @@
 # construct solver for fixed-point iterations
-function build_fpsolver(alg, fpalg::Union{NLFunctional, NLAnderson}, u, uEltypeNoUnits,
-        uBottomEltypeNoUnits, ::Val{true})
+function build_fpsolver(
+        alg, fpalg::Union{NLFunctional, NLAnderson}, u, uEltypeNoUnits,
+        uBottomEltypeNoUnits, ::Val{true}
+    )
     # no fixed-point iterations if the algorithm is constrained
     isconstrained(alg) && return
 
@@ -30,11 +32,13 @@ function build_fpsolver(alg, fpalg::Union{NLFunctional, NLAnderson}, u, uEltypeN
     # build solver
     ηold = one(uTolType)
 
-    FPSolver{typeof(fpalg), true, uTolType, typeof(fpcache)}(fpalg, uTolType(fpalg.κ), uTolType(fpalg.fast_convergence_cutoff), ηold, 10000, fpalg.max_iter, SlowConvergence, fpcache, 0)
+    return FPSolver{typeof(fpalg), true, uTolType, typeof(fpcache)}(fpalg, uTolType(fpalg.κ), uTolType(fpalg.fast_convergence_cutoff), ηold, 10000, fpalg.max_iter, SlowConvergence, fpcache, 0)
 end
 
-function build_fpsolver(alg, fpalg::Union{NLFunctional, NLAnderson}, u, uEltypeNoUnits,
-        uBottomEltypeNoUnits, ::Val{false})
+function build_fpsolver(
+        alg, fpalg::Union{NLFunctional, NLAnderson}, u, uEltypeNoUnits,
+        uBottomEltypeNoUnits, ::Val{false}
+    )
     # no fixed-point iterations if the algorithm is constrained
     isconstrained(alg) && return
 
@@ -55,19 +59,23 @@ function build_fpsolver(alg, fpalg::Union{NLFunctional, NLAnderson}, u, uEltypeN
         dzold = u
         z₊old = u
 
-        fpcache = FPAndersonConstantCache(dz, dzold, z₊old, Δz₊s, Q, R, γs, 0,
+        fpcache = FPAndersonConstantCache(
+            dz, dzold, z₊old, Δz₊s, Q, R, γs, 0,
             fpalg.aa_start,
-            fpalg.droptol)
+            fpalg.droptol
+        )
     end
 
     # build solver
     ηold = one(uTolType)
 
-    FPSolver{typeof(fpalg), false, uTolType, typeof(fpcache)}(fpalg, uTolType(fpalg.κ),
+    return FPSolver{typeof(fpalg), false, uTolType, typeof(fpcache)}(
+        fpalg, uTolType(fpalg.κ),
         uTolType(fpalg.fast_convergence_cutoff),
         ηold, 10_000,
         fpalg.max_iter,
-        SlowConvergence, fpcache, 0)
+        SlowConvergence, fpcache, 0
+    )
 end
 
 ## resize
@@ -79,9 +87,9 @@ function resize_fpsolver!(integrator::DDEIntegrator, i::Int)
         resize!(fpsolver, integrator, i)
     end
 
-    nothing
+    return nothing
 end
 
 function Base.resize!(fpsolver::FPSolver, integrator::DDEIntegrator, i::Int)
-    resize!(fpsolver.cache, fpsolver, integrator, i)
+    return resize!(fpsolver.cache, fpsolver, integrator, i)
 end
