@@ -13,12 +13,14 @@ function OrdinaryDiffEqCore.loopfooter!(integrator::DDEIntegrator)
         end
     end
 
-    nothing
+    return nothing
 end
 
 # save current state of the integrator
-function DiffEqBase.savevalues!(integrator::HistoryODEIntegrator, force_save = false,
-        reduce_size = false)::Tuple{Bool, Bool}
+function DiffEqBase.savevalues!(
+        integrator::HistoryODEIntegrator, force_save = false,
+        reduce_size = false
+    )::Tuple{Bool, Bool}
     integrator.saveiter += 1
     # TODO: save history only for a subset of components
     copyat_or_push!(integrator.sol.t, integrator.saveiter, integrator.t)
@@ -28,15 +30,19 @@ function DiffEqBase.savevalues!(integrator::HistoryODEIntegrator, force_save = f
     copyat_or_push!(integrator.sol.k, integrator.saveiter_dense, integrator.k)
 
     if iscomposite(integrator.alg)
-        copyat_or_push!(integrator.sol.alg_choice, integrator.saveiter,
-            integrator.cache.current)
+        copyat_or_push!(
+            integrator.sol.alg_choice, integrator.saveiter,
+            integrator.cache.current
+        )
     end
 
-    true, true
+    return true, true
 end
 
-function DiffEqBase.savevalues!(integrator::DDEIntegrator, force_save = false,
-        reduce_size = false)::Tuple{Bool, Bool}
+function DiffEqBase.savevalues!(
+        integrator::DDEIntegrator, force_save = false,
+        reduce_size = false
+    )::Tuple{Bool, Bool}
     ode_integrator = integrator.integrator
 
     # update time of ODE integrator (can be slightly modified (< 10ϵ) because of time stops)
@@ -61,8 +67,10 @@ function DiffEqBase.savevalues!(integrator::DDEIntegrator, force_save = false,
     end
 
     # update history
-    saved, savedexactly = DiffEqBase.savevalues!(ode_integrator, force_save,
-        false) # reduce_size = false
+    saved, savedexactly = DiffEqBase.savevalues!(
+        ode_integrator, force_save,
+        false
+    ) # reduce_size = false
 
     # check that history was actually updated
     saved || error("dense history could not be updated")
@@ -80,7 +88,7 @@ function DiffEqBase.savevalues!(integrator::DDEIntegrator, force_save = false,
     ode_integrator.dtcache = ode_integrator.dt
 
     # update solution
-    OrdinaryDiffEqCore._savevalues!(integrator, force_save, reduce_size)
+    return OrdinaryDiffEqCore._savevalues!(integrator, force_save, reduce_size)
 end
 
 # clean up the solution of the integrator
@@ -94,8 +102,10 @@ function SciMLBase.postamble!(integrator::HistoryODEIntegrator)
         copyat_or_push!(integrator.sol.k, integrator.saveiter_dense, integrator.k)
 
         if iscomposite(integrator.alg)
-            copyat_or_push!(integrator.sol.alg_choice, integrator.saveiter,
-                integrator.cache.current)
+            copyat_or_push!(
+                integrator.sol.alg_choice, integrator.saveiter,
+                integrator.cache.current
+            )
         end
     end
 
@@ -103,7 +113,7 @@ function SciMLBase.postamble!(integrator::HistoryODEIntegrator)
     resize!(integrator.sol.u, integrator.saveiter)
     resize!(integrator.sol.k, integrator.saveiter_dense)
 
-    nothing
+    return nothing
 end
 
 function SciMLBase.postamble!(integrator::DDEIntegrator)
@@ -111,7 +121,7 @@ function SciMLBase.postamble!(integrator::DDEIntegrator)
     SciMLBase.postamble!(integrator.integrator)
 
     # clean solution of the DDE integrator
-    OrdinaryDiffEqCore._postamble!(integrator)
+    return OrdinaryDiffEqCore._postamble!(integrator)
 end
 
 # perform next integration step
@@ -135,17 +145,19 @@ function OrdinaryDiffEqCore.perform_step!(integrator::DDEIntegrator)
     # update ODE integrator to next time interval together with correct interpolation
     advance_or_update_ode_integrator!(integrator)
 
-    nothing
+    return nothing
 end
 
 # DefaultCache sumtype does lazy initializations of sub-caches
 # Need to overload this function so that the history function has initialized caches
 # https://github.com/SciML/DelayDiffEq.jl/issues/329
-function OrdinaryDiffEqCore.perform_step!(integrator::DDEIntegrator,
-        cache::OrdinaryDiffEqCore.DefaultCache, repeat_step = false)
+function OrdinaryDiffEqCore.perform_step!(
+        integrator::DDEIntegrator,
+        cache::OrdinaryDiffEqCore.DefaultCache, repeat_step = false
+    )
     algs = integrator.alg.algs
     OrdinaryDiffEqCore.init_ith_default_cache(cache, algs, cache.current)
-    if cache.current == 1
+    return if cache.current == 1
         integrator.history.integrator.cache.cache1 = cache.cache1
         OrdinaryDiffEqCore.perform_step!(integrator, @inbounds(cache.cache1), repeat_step)
     elseif cache.current == 2
@@ -178,12 +190,12 @@ function DiffEqBase.initialize!(integrator::DDEIntegrator)
         copyat_or_push!(ode_integrator.k, i, integrator.k[i])
     end
 
-    nothing
+    return nothing
 end
 
 # signal the integrator that state u was modified
 function DiffEqBase.u_modified!(integrator::DDEIntegrator, bool::Bool)
-    integrator.u_modified = bool
+    return integrator.u_modified = bool
 end
 
 # return next integration time step
@@ -192,12 +204,12 @@ DiffEqBase.get_proposed_dt(integrator::DDEIntegrator) = integrator.dtpropose
 # set next integration time step
 function DiffEqBase.set_proposed_dt!(integrator::DDEIntegrator, dt)
     integrator.dtpropose = dt
-    nothing
+    return nothing
 end
 
 # obtain caches
 function DiffEqBase.get_tmp_cache(integrator::DDEIntegrator)
-    get_tmp_cache(integrator, integrator.alg, integrator.cache)
+    return get_tmp_cache(integrator, integrator.alg, integrator.cache)
 end
 DiffEqBase.user_cache(integrator::DDEIntegrator) = user_cache(integrator.cache)
 DiffEqBase.u_cache(integrator::DDEIntegrator) = u_cache(integrator.cache)
@@ -222,13 +234,15 @@ function Base.resize!(integrator::DDEIntegrator, cache, i)
     OrdinaryDiffEqCore.resize_J_W!(cache, integrator, i)
     resize_non_user_cache!(integrator, cache, i)
     resize_fpsolver!(integrator, i)
-    nothing
+    return nothing
 end
 
 DiffEqBase.resize_non_user_cache!(integrator::DDEIntegrator, cache, i) = nothing
 
-function DiffEqBase.resize_non_user_cache!(integrator::DDEIntegrator,
-        cache::RosenbrockMutableCache, i)
+function DiffEqBase.resize_non_user_cache!(
+        integrator::DDEIntegrator,
+        cache::RosenbrockMutableCache, i
+    )
     cache.J = similar(cache.J, i, i)
     cache.W = similar(cache.W, i, i)
 
@@ -242,7 +256,7 @@ function DiffEqBase.resize_non_user_cache!(integrator::DDEIntegrator,
         OrdinaryDiffEqDifferentiation.resize_grad_config!(cache.grad_config, i)
     end
 
-    nothing
+    return nothing
 end
 
 # delete component(s)
@@ -258,12 +272,12 @@ function Base.deleteat!(integrator::DDEIntegrator, idxs)
     for c in full_cache(integrator)
         deleteat!(c, idxs)
     end
-    deleteat_non_user_cache!(integrator, integrator.cache, i)
+    return deleteat_non_user_cache!(integrator, integrator.cache, i)
 end
 
 function DiffEqBase.deleteat_non_user_cache!(integrator::DDEIntegrator, cache, idxs)
     i = length(integrator.u)
-    resize_non_user_cache!(integrator, cache, i)
+    return resize_non_user_cache!(integrator, cache, i)
 end
 
 # add component(s)
@@ -279,34 +293,36 @@ function DiffEqBase.addat!(integrator::DDEIntegrator, idxs)
     for c in full_cache(integrator)
         addat!(c, idxs)
     end
-    addat_non_user_cache!(integrator, integrator.cache, idxs)
+    return addat_non_user_cache!(integrator, integrator.cache, idxs)
 end
 
 function DiffEqBase.addat_non_user_cache!(integrator::DDEIntegrator, cache, idxs)
     i = length(integrator.u)
-    resize_non_user_cache!(integrator, cache, i)
+    return resize_non_user_cache!(integrator, cache, i)
 end
 
 # error check
 function SciMLBase.last_step_failed(integrator::DDEIntegrator)
-    integrator.last_stepfail && !integrator.opts.adaptive
+    return integrator.last_stepfail && !integrator.opts.adaptive
 end
 
 # terminate integration
 function DiffEqBase.terminate!(integrator::DDEIntegrator, retcode = ReturnCode.Terminated)
     integrator.sol = SciMLBase.solution_new_retcode(integrator.sol, retcode)
     integrator.opts.tstops.valtree = typeof(integrator.opts.tstops.valtree)()
-    nothing
+    return nothing
 end
 
 # integrator can be reinitialized
 SciMLBase.has_reinit(::HistoryODEIntegrator) = true
 SciMLBase.has_reinit(integrator::DDEIntegrator) = true
 
-function DiffEqBase.reinit!(integrator::HistoryODEIntegrator, u0 = integrator.sol.prob.u0;
+function DiffEqBase.reinit!(
+        integrator::HistoryODEIntegrator, u0 = integrator.sol.prob.u0;
         t0 = integrator.sol.prob.tspan[1],
         tf = integrator.sol.prob.tspan[end],
-        erase_sol = true)
+        erase_sol = true
+    )
     # reinit initial values of the integrator
     if isinplace(integrator.sol.prob)
         recursivecopy!(integrator.u, u0)
@@ -337,7 +353,7 @@ function DiffEqBase.reinit!(integrator::HistoryODEIntegrator, u0 = integrator.so
         integrator.saveiter_dense = 1
     end
 
-    nothing
+    return nothing
 end
 
 """
@@ -350,7 +366,8 @@ end
 Reinitialize `integrator` with (optionally) different initial state `u0`, different
 integration interval from `t0` to `tf`, and erased solution if `erase_sol = true`.
 """
-function DiffEqBase.reinit!(integrator::DDEIntegrator, u0 = integrator.sol.prob.u0;
+function DiffEqBase.reinit!(
+        integrator::DDEIntegrator, u0 = integrator.sol.prob.u0;
         t0 = integrator.sol.prob.tspan[1],
         tf = integrator.sol.prob.tspan[end],
         erase_sol = true,
@@ -358,12 +375,13 @@ function DiffEqBase.reinit!(integrator::DDEIntegrator, u0 = integrator.sol.prob.
         saveat = integrator.opts.saveat_cache,
         d_discontinuities = integrator.opts.d_discontinuities_cache,
         order_discontinuity_t0 = t0 == integrator.sol.prob.tspan[1] &&
-                                 u0 == integrator.sol.prob.u0 ?
-                                 integrator.order_discontinuity_t0 : 0,
+            u0 == integrator.sol.prob.u0 ?
+            integrator.order_discontinuity_t0 : 0,
         reset_dt = iszero(integrator.dtcache) &&
-                   integrator.opts.adaptive,
+            integrator.opts.adaptive,
         reinit_callbacks = true, initialize_save = true,
-        reinit_cache = true)
+        reinit_cache = true
+    )
     # reinit history
     reinit!(integrator.integrator, u0; t0 = t0, tf = tf, erase_sol = true)
 
@@ -389,22 +407,25 @@ function DiffEqBase.reinit!(integrator::DDEIntegrator, u0 = integrator.sol.prob.
     # reinit time stops, time points at which solution is saved, and discontinuities
     tType = typeof(integrator.t)
     tspan = (tType(t0), tType(tf))
-    integrator.opts.tstops = OrdinaryDiffEqCore.initialize_tstops(tType, tstops,
-        d_discontinuities, tspan)
+    integrator.opts.tstops = OrdinaryDiffEqCore.initialize_tstops(
+        tType, tstops,
+        d_discontinuities, tspan
+    )
     integrator.opts.saveat = OrdinaryDiffEqCore.initialize_saveat(tType, saveat, tspan)
     integrator.opts.d_discontinuities = OrdinaryDiffEqCore.initialize_d_discontinuities(
         Discontinuity{
             tType,
-            Int
+            Int,
         },
         d_discontinuities,
-        tspan)
+        tspan
+    )
 
     # update order of initial discontinuity and propagated discontinuities
     integrator.order_discontinuity_t0 = order_discontinuity_t0
     maximum_order = OrdinaryDiffEqCore.alg_maximum_order(integrator.alg)
     tstops_propagated,
-    d_discontinuities_propagated = initialize_tstops_d_discontinuities_propagated(
+        d_discontinuities_propagated = initialize_tstops_d_discontinuities_propagated(
         tType,
         tstops,
         d_discontinuities,
@@ -412,7 +433,8 @@ function DiffEqBase.reinit!(integrator::DDEIntegrator, u0 = integrator.sol.prob.
         order_discontinuity_t0,
         maximum_order,
         integrator.sol.prob.constant_lags,
-        integrator.sol.prob.neutral)
+        integrator.sol.prob.neutral
+    )
     integrator.tstops_propagated = tstops_propagated
     integrator.d_discontinuities_propagated = d_discontinuities_propagated
 
@@ -447,7 +469,8 @@ function DiffEqBase.reinit!(integrator::DDEIntegrator, u0 = integrator.sol.prob.
         if order_discontinuity_t0 ≤ OrdinaryDiffEqCore.alg_maximum_order(integrator.alg)
             resize!(integrator.tracked_discontinuities, 1)
             integrator.tracked_discontinuities[1] = Discontinuity(
-                integrator.tdir * integrator.t, order_discontinuity_t0)
+                integrator.tdir * integrator.t, order_discontinuity_t0
+            )
         else
             resize!(integrator.tracked_discontinuities, 0)
         end
@@ -480,7 +503,7 @@ function DiffEqBase.reinit!(integrator::DDEIntegrator, u0 = integrator.sol.prob.
         DiffEqBase.initialize!(integrator)
     end
 
-    nothing
+    return nothing
 end
 
 function DiffEqBase.auto_dt_reset!(integrator::DDEIntegrator)
@@ -497,56 +520,60 @@ function DiffEqBase.auto_dt_reset!(integrator::DDEIntegrator)
 
     # determine initial time step
     ode_prob = ODEProblem(f, prob.u0, prob.tspan, prob.p)
-    integrator.dt = OrdinaryDiffEqCore.ode_determine_initdt(u, t, tdir, dtmax, opts.abstol,
+    integrator.dt = OrdinaryDiffEqCore.ode_determine_initdt(
+        u, t, tdir, dtmax, opts.abstol,
         opts.reltol, opts.internalnorm,
-        ode_prob, integrator)
+        ode_prob, integrator
+    )
 
     # update statistics
     stats.nf += 2
 
-    nothing
+    return nothing
 end
 
 function DiffEqBase.add_tstop!(integrator::DDEIntegrator, t)
     integrator.tdir * (t - integrator.t) < 0 &&
         error("Tried to add a tstop that is behind the current time. This is strictly forbidden")
-    push!(integrator.opts.tstops, integrator.tdir * t)
+    return push!(integrator.opts.tstops, integrator.tdir * t)
 end
 
 function DiffEqBase.add_saveat!(integrator::DDEIntegrator, t)
     integrator.tdir * (t - integrator.t) < 0 &&
         error("Tried to add a saveat that is behind the current time. This is strictly forbidden")
-    push!(integrator.opts.saveat, integrator.tdir * t)
+    return push!(integrator.opts.saveat, integrator.tdir * t)
 end
 
 @inline function DiffEqBase.get_du(integrator::DDEIntegrator)
-    integrator.fsallast
+    return integrator.fsallast
 end
 
 @inline function DiffEqBase.get_du!(out, integrator::DDEIntegrator)
-    out .= integrator.fsallast
+    return out .= integrator.fsallast
 end
 
 SciMLBase.has_stats(::DDEIntegrator) = true
 
 function DiffEqBase.addsteps!(integrator::DDEIntegrator, args...)
-    OrdinaryDiffEqCore.ode_addsteps!(integrator, args...)
+    return OrdinaryDiffEqCore.ode_addsteps!(integrator, args...)
 end
 
-function DiffEqBase.change_t_via_interpolation!(integrator::DDEIntegrator,
+function DiffEqBase.change_t_via_interpolation!(
+        integrator::DDEIntegrator,
         t, modify_save_endpoint::Type{Val{T}} = Val{false},
-        reinitialize_alg = nothing) where {T}
-    OrdinaryDiffEqCore._change_t_via_interpolation!(integrator, t, modify_save_endpoint, reinitialize_alg)
+        reinitialize_alg = nothing
+    ) where {T}
+    return OrdinaryDiffEqCore._change_t_via_interpolation!(integrator, t, modify_save_endpoint, reinitialize_alg)
 end
 
 # tstops interface for PeriodicCallback support (issue #341)
 DiffEqBase.get_tstops(integrator::DDEIntegrator) = integrator.opts.tstops
 function DiffEqBase.get_tstops_array(integrator::DDEIntegrator)
-    DiffEqBase.get_tstops(integrator).valtree
+    return DiffEqBase.get_tstops(integrator).valtree
 end
 function DiffEqBase.get_tstops_max(integrator::DDEIntegrator)
     tstops_array = DiffEqBase.get_tstops_array(integrator)
-    isempty(tstops_array) ? integrator.sol.prob.tspan[end] : maximum(tstops_array)
+    return isempty(tstops_array) ? integrator.sol.prob.tspan[end] : maximum(tstops_array)
 end
 
 # update integrator when u is modified by callbacks
@@ -555,20 +582,26 @@ function OrdinaryDiffEqCore.handle_callback_modifiers!(integrator::DDEIntegrator
 
     # update heap of discontinuities
     # discontinuity is assumed to be of order 0, i.e. solution x is discontinuous
-    push!(integrator.opts.d_discontinuities,
-        Discontinuity(integrator.tdir * integrator.t, 0))
+    return push!(
+        integrator.opts.d_discontinuities,
+        Discontinuity(integrator.tdir * integrator.t, 0)
+    )
 end
 
 # recalculate interpolation data and update the ODE integrator
-function DiffEqBase.reeval_internals_due_to_modification!(integrator::DDEIntegrator,
+function DiffEqBase.reeval_internals_due_to_modification!(
+        integrator::DDEIntegrator,
         ::Type{Val{not_initialization}} = Val{true};
-        callback_initializealg = nothing) where {not_initialization}
+        callback_initializealg = nothing
+    ) where {not_initialization}
     ode_integrator = integrator.integrator
 
     if integrator.isdae
-        SciMLBase.initialize_dae!(integrator,
+        SciMLBase.initialize_dae!(
+            integrator,
             isnothing(callback_initializealg) ? integrator.initializealg :
-            callback_initializealg)
+                callback_initializealg
+        )
         OrdinaryDiffEqCore.update_uprev!(integrator)
     end
     if not_initialization
@@ -590,12 +623,12 @@ function DiffEqBase.reeval_internals_due_to_modification!(integrator::DDEIntegra
         ode_integrator.u = integrator.u
     end
 
-    integrator.u_modified = false
+    return integrator.u_modified = false
 end
 
 # perform one step
 function DiffEqBase.step!(integrator::DDEIntegrator)
-    @inbounds begin
+    return @inbounds begin
         if integrator.opts.advance_to_tstop
             while integrator.tdir * integrator.t < first(integrator.opts.tstops)
                 OrdinaryDiffEqCore.loopheader!(integrator)
