@@ -2,20 +2,22 @@ using DelayDiffEq, Test
 using Random
 Random.seed!(213)
 
-const CACHE_TEST_ALGS = [Vern7(), Euler(), Midpoint(), RK4(), SSPRK22(), SSPRK33(),
+const CACHE_TEST_ALGS = [
+    Vern7(), Euler(), Midpoint(), RK4(), SSPRK22(), SSPRK33(),
     ORK256(), CarpenterKennedy2N54(), SHLDDRK64(), DGLDDRK73_C(),
     CFRLDDRK64(), TSLDDRK74(),
     CKLLSRK43_2(),
     ParsaniKetchesonDeconinck3S32(),
     BS3(), BS5(), DP5(), DP8(), Feagin10(), Feagin12(), Feagin14(), TanYam7(),
     Tsit5(), TsitPap8(), Vern6(), Vern7(), Vern8(), Vern9(), OwrenZen3(), OwrenZen4(),
-    OwrenZen5()]
+    OwrenZen5(),
+]
 
 function f(du, u, h, p, t)
     for i in 1:length(u)
         du[i] = (0.3 / length(u)) * u[i]
     end
-    nothing
+    return nothing
 end
 
 condition(u, t, integrator) = 1 - maximum(u)
@@ -27,11 +29,13 @@ function affect!(integrator)
     Θ = rand() / 5 + 0.25
     u[maxidx] = Θ
     u[end] = 1 - Θ
-    nothing
+    return nothing
 end
 
-const prob = DDEProblem(f, [0.2], nothing, (0.0, 10.0);
-    callback = ContinuousCallback(condition, affect!))
+const prob = DDEProblem(
+    f, [0.2], nothing, (0.0, 10.0);
+    callback = ContinuousCallback(condition, affect!)
+)
 
 println("Check for stochastic errors")
 for i in 1:10
